==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_analysisresultCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_analysisresult;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_analysisresultRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_analysisresultdetailRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class Msdyn_analysisresultCollectionRequest extends CollectionPageEntityRequest<Msdyn_analysisresult, Msdyn_analysisresultRequest>{

    protected ContextPath contextPath;

    public Msdyn_analysisresultCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_analysisresult.class, cp -> new Msdyn_analysisresultRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_analysisresult_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_analysisresult_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_analysisresult_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_analysisresult_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_analysisresult_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_analysisresult_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_analysisresult_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_analysisresult_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_analysisresult_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_analysisresult_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_analysisresult_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_analysisresult_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_analysisresult_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_analysisresult_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_analysisresult_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_analysisresult_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_analysisresult_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_analysisresult_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_analysisresult_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_analysisresult_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_analysisresult_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_analysisresult_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_analysisresult_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_analysisresult_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_analysisresult_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_analysisresult_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_analysisresult_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_analysisresult_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public Msdyn_analysisresultdetailCollectionRequest msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult() {
        return new Msdyn_analysisresultdetailCollectionRequest(contextPath.addSegment("msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult"), Optional.empty());
    }

    public Msdyn_analysisresultdetailRequest msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult(String msdyn_analysisresultdetailid) {
        return new Msdyn_analysisresultdetailRequest(contextPath.addSegment("msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult").addKeys(new NameValue(msdyn_analysisresultdetailid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/Msdyn_analysisresultCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Msdyn_analysisresult;
import microsoft.dynamics.crm.entity.request.AsyncoperationRequest;
import microsoft.dynamics.crm.entity.request.BulkdeletefailureRequest;
import microsoft.dynamics.crm.entity.request.DuplicaterecordRequest;
import microsoft.dynamics.crm.entity.request.MailboxtrackingfolderRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_analysisresultRequest;
import microsoft.dynamics.crm.entity.request.Msdyn_analysisresultdetailRequest;
import microsoft.dynamics.crm.entity.request.PrincipalobjectattributeaccessRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;

public class Msdyn_analysisresultCollectionRequest extends CollectionPageEntityRequest<Msdyn_analysisresult, Msdyn_analysisresultRequest>{

    protected ContextPath contextPath;

    public Msdyn_analysisresultCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Msdyn_analysisresult.class, cp -> new Msdyn_analysisresultRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public SyncerrorCollectionRequest msdyn_analysisresult_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("msdyn_analysisresult_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest msdyn_analysisresult_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("msdyn_analysisresult_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_analysisresult_DuplicateMatchingRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateMatchingRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_analysisresult_DuplicateMatchingRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateMatchingRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public DuplicaterecordCollectionRequest msdyn_analysisresult_DuplicateBaseRecord() {
        return new DuplicaterecordCollectionRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateBaseRecord"), Optional.empty());
    }

    public DuplicaterecordRequest msdyn_analysisresult_DuplicateBaseRecord(String duplicateid) {
        return new DuplicaterecordRequest(contextPath.addSegment("msdyn_analysisresult_DuplicateBaseRecord").addKeys(new NameValue(duplicateid.toString())), Optional.empty());
    }

    public AsyncoperationCollectionRequest msdyn_analysisresult_AsyncOperations() {
        return new AsyncoperationCollectionRequest(contextPath.addSegment("msdyn_analysisresult_AsyncOperations"), Optional.empty());
    }

    public AsyncoperationRequest msdyn_analysisresult_AsyncOperations(String asyncoperationid) {
        return new AsyncoperationRequest(contextPath.addSegment("msdyn_analysisresult_AsyncOperations").addKeys(new NameValue(asyncoperationid.toString())), Optional.empty());
    }

    public MailboxtrackingfolderCollectionRequest msdyn_analysisresult_MailboxTrackingFolders() {
        return new MailboxtrackingfolderCollectionRequest(contextPath.addSegment("msdyn_analysisresult_MailboxTrackingFolders"), Optional.empty());
    }

    public MailboxtrackingfolderRequest msdyn_analysisresult_MailboxTrackingFolders(String mailboxtrackingfolderid) {
        return new MailboxtrackingfolderRequest(contextPath.addSegment("msdyn_analysisresult_MailboxTrackingFolders").addKeys(new NameValue(mailboxtrackingfolderid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest msdyn_analysisresult_ProcessSession() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("msdyn_analysisresult_ProcessSession"), Optional.empty());
    }

    public ProcesssessionRequest msdyn_analysisresult_ProcessSession(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("msdyn_analysisresult_ProcessSession").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public BulkdeletefailureCollectionRequest msdyn_analysisresult_BulkDeleteFailures() {
        return new BulkdeletefailureCollectionRequest(contextPath.addSegment("msdyn_analysisresult_BulkDeleteFailures"), Optional.empty());
    }

    public BulkdeletefailureRequest msdyn_analysisresult_BulkDeleteFailures(String bulkdeletefailureid) {
        return new BulkdeletefailureRequest(contextPath.addSegment("msdyn_analysisresult_BulkDeleteFailures").addKeys(new NameValue(bulkdeletefailureid.toString())), Optional.empty());
    }

    public PrincipalobjectattributeaccessCollectionRequest msdyn_analysisresult_PrincipalObjectAttributeAccesses() {
        return new PrincipalobjectattributeaccessCollectionRequest(contextPath.addSegment("msdyn_analysisresult_PrincipalObjectAttributeAccesses"), Optional.empty());
    }

    public PrincipalobjectattributeaccessRequest msdyn_analysisresult_PrincipalObjectAttributeAccesses(String principalobjectattributeaccessid) {
        return new PrincipalobjectattributeaccessRequest(contextPath.addSegment("msdyn_analysisresult_PrincipalObjectAttributeAccesses").addKeys(new NameValue(principalobjectattributeaccessid.toString())), Optional.empty());
    }

    public Msdyn_analysisresultdetailCollectionRequest msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult() {
        return new Msdyn_analysisresultdetailCollectionRequest(contextPath.addSegment("msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult"), Optional.empty());
    }

    public Msdyn_analysisresultdetailRequest msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult(String msdyn_analysisresultdetailid) {
        return new Msdyn_analysisresultdetailRequest(contextPath.addSegment("msdyn_msdyn_analysisresult_msdyn_analysisresultdetail_AnalysisResult").addKeys(new NameValue(msdyn_analysisresultdetailid.toString())), Optional.empty());
    }

}
